package cn.com.qmth.examcloud.support.fss;

import org.apache.commons.codec.binary.Hex;
import org.apache.commons.codec.digest.DigestUtils;
import org.apache.commons.lang3.ArrayUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.File;
import java.io.FileInputStream;
import java.security.MessageDigest;

public class FssHelper {

    private static final Logger log = LoggerFactory.getLogger(FssHelper.class);

    /**
     * 创建文件目录
     */
    public static boolean makeDirs(String dirPath) {
        if (StringUtils.isEmpty(dirPath)) {
            return false;
        }

        File dir = new File(dirPath);
        if (!dir.exists()) {
            return dir.mkdirs();
        }

        return true;
    }

    /**
     * 获取文件名(包含后缀名)
     */
    public static String getFileName(String filePath) {
        if (filePath != null) {
            filePath = filePath.replace("\\", "/");
            int index = filePath.lastIndexOf("/");
            if (index >= 0) {
                return filePath.substring(index + 1);
            }
        }

        return filePath;
    }

    /**
     * 获取文件MD5值
     */
    public static String getFileMD5(byte[] fileBytes) {
        if (ArrayUtils.isEmpty(fileBytes)) {
            throw new RuntimeException("文件大小不能为空！");
        }

        return DigestUtils.md5Hex(fileBytes);
    }

    /**
     * 获取文件的MD5值
     */
    public static String getFileMD5(File file) {
        if (file == null || !file.isFile()) {
            return null;
        }

        try (FileInputStream fis = new FileInputStream(file);) {
            MessageDigest md = MessageDigest.getInstance("MD5");

            int len;
            byte[] bytes = new byte[4096];
            while ((len = fis.read(bytes)) != -1) {
                md.update(bytes, 0, len);
            }

            return new String(Hex.encodeHex(md.digest()));
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            return null;
        }
    }

}
